sqlobject.tests.test_columns_order module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_columns_order module

class `sqlobject.tests.test_columns_order.` `SOColumnsOrder`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `age`
  `j` = so_columns_order
  property `name`
  property `parname`
  `q` = so_columns_order
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_columns_order.SOColumnsOrder`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_columns_order'
  property `surname`

`sqlobject.tests.test_columns_order.` `test_columns_order`()